aboutsummaryrefslogtreecommitdiff
path: root/bfd/cofflink.c
diff options
context:
space:
mode:
authorKim Knuttila <krk@cygnus>1996-01-29 19:31:34 +0000
committerKim Knuttila <krk@cygnus>1996-01-29 19:31:34 +0000
commitbdd2e7f1797de0511de1708366dcb146e806c329 (patch)
treef2e5e0671fa52ab3f592c37814dee5a074e04df4 /bfd/cofflink.c
parentfdb1821eb4d09e82442114f6b7e01c60f3b8e012 (diff)
downloadgdb-bdd2e7f1797de0511de1708366dcb146e806c329.zip
gdb-bdd2e7f1797de0511de1708366dcb146e806c329.tar.gz
gdb-bdd2e7f1797de0511de1708366dcb146e806c329.tar.bz2
Fixed exported names, removed a bad define
Diffstat (limited to 'bfd/cofflink.c')
-rw-r--r--bfd/cofflink.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/bfd/cofflink.c b/bfd/cofflink.c
index 2de8f98..999a81e 100644
--- a/bfd/cofflink.c
+++ b/bfd/cofflink.c
@@ -108,7 +108,7 @@ _bfd_coff_link_hash_table_create (abfd)
/* Create an entry in a COFF debug merge hash table. */
struct bfd_hash_entry *
-coff_debug_merge_hash_newfunc (entry, table, string)
+_bfd_coff_debug_merge_hash_newfunc (entry, table, string)
struct bfd_hash_entry *entry;
struct bfd_hash_table *table;
const char *string;
@@ -663,7 +663,7 @@ _bfd_coff_final_link (abfd, info)
sub = p->u.indirect.section->owner;
if (! sub->output_has_begun)
{
- if (! coff_link_input_bfd (&finfo, sub))
+ if (! _bfd_coff_link_input_bfd (&finfo, sub))
goto error_return;
sub->output_has_begun = true;
}
@@ -671,7 +671,7 @@ _bfd_coff_final_link (abfd, info)
else if (p->type == bfd_section_reloc_link_order
|| p->type == bfd_symbol_reloc_link_order)
{
- if (! coff_reloc_link_order (abfd, &finfo, o, p))
+ if (! _bfd_coff_reloc_link_order (abfd, &finfo, o, p))
goto error_return;
}
else
@@ -682,7 +682,7 @@ _bfd_coff_final_link (abfd, info)
}
}
/* Free up the buffers used by coff_link_input_bfd. */
coff_debug_merge_hash_table_free (&finfo.debug_merge);
debug_merge_allocated = false;
@@ -742,12 +742,12 @@ _bfd_coff_final_link (abfd, info)
/* Write out the global symbols. */
finfo.failed = false;
- coff_link_hash_traverse (coff_hash_table (info), coff_write_global_sym,
+ coff_link_hash_traverse (coff_hash_table (info), _bfd_coff_write_global_sym,
(PTR) &finfo);
if (finfo.failed)
goto error_return;
/* The outsyms buffer is used by coff_write_global_sym. */
if (finfo.outsyms != NULL)
{
free (finfo.outsyms);
@@ -1016,7 +1016,7 @@ process_embedded_commands (output_bfd, info, abfd)
handles all the sections and relocations of the input file at once. */
boolean
-coff_link_input_bfd (finfo, input_bfd)
+_bfd_coff_link_input_bfd (finfo, input_bfd)
struct coff_final_link_info *finfo;
bfd *input_bfd;
{
@@ -1901,7 +1901,7 @@ coff_link_input_bfd (finfo, input_bfd)
/* Write out a global symbol. Called via coff_link_hash_traverse. */
boolean
-coff_write_global_sym (h, data)
+_bfd_coff_write_global_sym (h, data)
struct coff_link_hash_entry *h;
PTR data;
{
@@ -2032,7 +2032,7 @@ coff_write_global_sym (h, data)
/* Handle a link order which is supposed to generate a reloc. */
boolean
-coff_reloc_link_order (output_bfd, finfo, output_section, link_order)
+_bfd_coff_reloc_link_order (output_bfd, finfo, output_section, link_order)
bfd *output_bfd;
struct coff_final_link_info *finfo;
asection *output_section;
@@ -682,7 +682,7 @@ _bfd_coff_final_link (abfd, info)
}
}
- /* Free up the buffers used by coff_link_input_bfd. */
+ /* Free up the buffers used by _bfd_coff_link_input_bfd. */
coff_debug_merge_hash_table_free (&finfo.debug_merge);
debug_merge_allocated = false;
@@ -742,12 +742,12 @@ _bfd_coff_final_link (abfd, info)
if (finfo.failed)
goto error_return;
- /* The outsyms buffer is used by coff_write_global_sym. */
+ /* The outsyms buffer is used by _bfd_coff_write_global_sym. */
if (finfo.outsyms != NULL)
{